==============
Change history
==============

0.1.2 (2022-06-16)
==================

* Added ``SharingConfigsMixin``
* Increased test coverage
* Created test application to exchange color-themes
* Documented the usage of the library in README with the example for the test application


0.1.1 (2022-05-24)
==================

* Fixed various bugs (#50)


0.1.0 (2022-05-13)
==================

* Initial release.
